Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1450)

Unified Diff: src/interpreter/interpreter.cc

Issue 2571563004: [Turbofan] Implement super calls with spread bytecode in assembly code. (Closed)
Patch Set: Update builtins for new push args modes Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/interpreter/interpreter.cc
diff --git a/src/interpreter/interpreter.cc b/src/interpreter/interpreter.cc
index 60c5e595afa004eb8f1e4d1b5f1126492d376cee..942d233ee5c1f67d50ecdc6c48cff42f69fbb776 100644
--- a/src/interpreter/interpreter.cc
+++ b/src/interpreter/interpreter.cc
@@ -2159,22 +2159,22 @@ void Interpreter::DoCallJSRuntime(InterpreterAssembler* assembler) {
__ Dispatch();
}
-// NewWithSpread <first_arg> <arg_count>
+// NewWithSpread <constructor> <first_arg> <arg_count>
//
// Call the constructor in |first_arg| with the new.target in |first_arg + 1|
// for the |arg_count - 2| following arguments. The final argument is always a
// spread.
//
void Interpreter::DoNewWithSpread(InterpreterAssembler* assembler) {
- Node* first_arg_reg = __ BytecodeOperandReg(0);
+ Node* new_target = __ GetAccumulator();
+ Node* constructor_reg = __ BytecodeOperandReg(0);
+ Node* constructor = __ LoadRegister(constructor_reg);
+ Node* first_arg_reg = __ BytecodeOperandReg(1);
Node* first_arg = __ RegisterLocation(first_arg_reg);
- Node* args_count = __ BytecodeOperandCount(1);
+ Node* args_count = __ BytecodeOperandCount(2);
Node* context = __ GetContext();
-
- // Call into Runtime function NewWithSpread which does everything.
- Node* runtime_function = __ Int32Constant(Runtime::kNewWithSpread);
- Node* result =
- __ CallRuntimeN(runtime_function, context, first_arg, args_count);
+ Node* result = __ CallConstructWithSpread(constructor, context, new_target,
+ first_arg, args_count);
__ SetAccumulator(result);
__ Dispatch();
}
@@ -2159,22 +2159,22 @@ void Interpreter::DoCallJSRuntime(InterpreterAssembler* assembler) {
//
-// Call the constructor in |first_arg| with the new.target in |first_arg + 1|
-// for the |arg_count - 2| following arguments. The final argument is always a
-// spread.
+// Call the constructor in |constructor| with the first argument in register
+// |first_arg| and |arg_count| arguments in subsequent registers. The final
+// argument is always a spread. The new.target is in the accumulator.
//
void Interpreter::DoNewWithSpread(InterpreterAssembler* assembler) {

Powered by Google App Engine
This is Rietveld 408576698